@@ -505,7 +505,7 @@ def plot(dag, filename):
     dot.render(filename, view=True)
 
 
-# random orient a PDAG to a DAG
+# randomly orient a PDAG to a DAG
 def pdag2dag(pdag):
     pdag_dc = deepcopy(pdag)
     dag = {var: {'par': [] + pdag[var]['par'], 'nei': []} for var in pdag}
@@ -622,7 +622,8 @@ def dag2cpdag(dag):
                     for par_nei in cpdag[nei]['par']:
                         if par_nei in cpdag[var]['nei'] and len(cpdag[par_nei]['par']) > 0:
                             for par_par_nei in cpdag[par_nei]['par']:
-                                if par_par_nei in cpdag[var]['nei']:
+                                if par_par_nei in cpdag[var]['nei'] and par_par_nei not in cpdag[nei]['par'] + \
+                                        cpdag[nei]['nei'] and nei not in cpdag[par_par_nei]['par']:
                                     cpdag[var]['nei'].remove(nei)
                                     cpdag[nei]['nei'].remove(var)
                                     cpdag[nei]['par'].append(var)
